@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.20.1";
+        "11.0.21";
 
     private static final String java_version_date =
-        "2023-08-24";
+        "2023-10-17";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.20.1+1";
+        "11.0.21+9";
 
     private static final String VERSION_NUMBER =
-        "11.0.20.1";
+        "11.0.21";
 
     private static final String VERSION_BUILD =
-        "1";
+        "9";
 
     private static final String VERSION_PRE =
         "";
