@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -726,6 +726,14 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Ora universale e koordinuar",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "Ora standarde e Mauritiusit",
                "",
@@ -1273,16 +1281,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Feniks" },
             { "timezone.excity.Asia/Katmandu", "Katmandu" },
@@ -1310,6 +1309,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
             { "timezone.excity.America/North_Dakota/Beulah", "Beula, Dakota e Veriut" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fixhi" },
             { "timezone.excity.Europe/Gibraltar", "Gjibraltar" },
             { "Europe/Jersey", GMT },
@@ -1330,6 +1330,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Truk", "\u00c7uk" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
@@ -1474,6 +1475,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Dhule" },
             { "timezone.excity.America/Grand_Turk", "Turku i Madh" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "timezone.excity.America/Indiana/Petersburg", "Pet\u00ebrsburg, Indiana" },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Uinipeg" },
@@ -1522,6 +1524,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Konakri" },
             { "timezone.excity.Asia/Jakarta", "Xhakart\u00eb" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1543,6 +1546,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Ishulli i Manit" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Kura\u00e7ao" },
@@ -1551,6 +1555,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Gujan\u00eb" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Paris" },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
@@ -1570,16 +1575,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "\u00c7ita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Gryka Inlet" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santarem" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
@@ -1665,17 +1660,8 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1696,6 +1682,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Kujaba" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azore" },
             { "timezone.excity.Australia/Melbourne", "Melburn" },
             { "America/Montreal", America_Eastern },
@@ -1723,6 +1710,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Rexhina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Gjiri i Bubullim\u00ebs" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1746,16 +1734,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunsion" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Ora universale e koordinuar",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Kishineu" },
             { "timezone.excity.America/Moncton", "Monkton" },
             { "Asia/Singapore", Singapore },
@@ -1811,6 +1790,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Pashk\u00eb" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1837,6 +1817,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Kreston" },
             { "timezone.excity.Africa/Cairo", "Kajro" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Varshav\u00eb" },
             { "Europe/Skopje", Europe_Central },
@@ -1847,16 +1828,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1894,16 +1865,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Antarctica/DumontDUrville", "Dumont-d\u2019Urvil\u00eb" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1916,6 +1877,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monako" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1938,6 +1900,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1981,11 +1944,13 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho-\u00c7i-Min" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makasar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Ekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sofje" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1998,6 +1963,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Kalkut\u00eb" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Africa/Ceuta", "Theuta" },
             { "Africa/Libreville", Africa_Western },
@@ -2007,6 +1973,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hong-Kong" },
             { "timezone.excity.America/Port-au-Prince", "Port-o-Prins" },
             { "America/Tijuana", America_Pacific },
@@ -2015,8 +1982,8 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kuaxhalein" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisbon\u00eb" },
             { "timezone.excity.Pacific/Gambier", "Gambier" },
@@ -2024,6 +1991,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhje" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -2034,17 +2002,8 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "\u00c7atman" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Kolombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port-Moresbi" },
@@ -2062,6 +2021,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "Kordoba" },
             { "timezone.excity.America/Cambridge_Bay", "Gjiri i Kembrixhit" },
@@ -2081,6 +2041,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sidnej" },
             { "timezone.excity.Asia/Qatar", "Katar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Dejvis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2135,6 +2096,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
             { "Asia/Kamchatka", Kamchatka },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelajde" },
@@ -2181,31 +2143,11 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stenli" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Thimphu", "Thimpu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala-Lumpur" },
@@ -2213,16 +2155,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Uag\u00ebdugu" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "\u00c7agos" },
             { "timezone.excity.Asia/Kabul", "Kabul" },
